
/***************************************************************************
 *   This file is part of Aspect, a simple PEC tool.                       *
 *                                                                         *
 *   Copyright (C) 2006-2007 by Wolfgang Hoffmann <woho@woho.de>           *
 *                                                                         *
 *   This program is free software, licensed under the GPL v2.             *
 *   See the file COPYING for more details.                                *
 ***************************************************************************/


#ifndef ASPECT_MAINWINDOW_H
#define ASPECT_MAINWINDOW_H


#include "data.h"

#include <QDir>
#include <QMainWindow>
#include <QList>
#include <QVector>

class QGraphicsScene;
class QStandardItem;
class QStandardItemModel;
class McuLogDialog;
class McuSerial;

namespace Ui { class MainWindow; };


class MainWindow: public QMainWindow
    {
    Q_OBJECT

public:
    MainWindow();
    ~MainWindow();

public slots:
    void on_actionQuit_triggered();
    void on_actionAbout_Aspect_triggered();
    void on_actionAbout_Qt_triggered();

    void on_actionMCU_Log_View_triggered();

    void on_mcuPort_activated(const QString &qsPort);
    void on_mcuAutoconnect_toggled(bool bOn);
    void on_mcuConnect_toggled(bool bOn);
    void on_mcuSettingsTracking_activated(int nSpeed);
    void on_mcuSettingsPec_activated(int nIndex);
    void on_mcuSettingsIntelly_activated(int nIndex);
    void on_mcuSettingsRefresh_clicked();
    void on_mcuCommandSend_clicked();

    void on_actionOpen_PE_Data_triggered();
    void on_widgetPeMcu_dataPeChanged(IPeRawData *pData);
    void on_widgetPeIris_dataPeChanged(IPeRawData *pData);

    void on_peProcCombining_activated(int nMethod);
    void on_peProcSmoothWidth_valueChanged(int nWidth);
    void on_peProcDrift_valueChanged(double dfDrift);
    void on_peProcScale_valueChanged(double dfScale);

    void on_actionOpen_PEC_Table_triggered();
    void on_actionSave_PEC_Table_triggered();
    void on_actionGet_PEC_Table_triggered();
    void on_actionPut_PEC_Table_triggered();
    void changePecItem(QStandardItem *pItem);
    void on_pecFactor_valueChanged(int nFactor);
    void on_pecGraphOffset_valueChanged(double dfOffset);
    void on_pecMountQuery_clicked();
    void on_pecWormWheel_valueChanged(int nTeeth);
    void on_pecTraversal_activated(int nDirection);
    void on_pecAccel_valueChanged(double dfAccel);
    void on_pecCalculate_clicked();

    void on_pecProfileOffset_valueChanged(double dfOffset);
    void on_pecProfileDrift_valueChanged(double dfDrift);
    void on_pecProfileOpen_clicked();
    void on_pecProfileSave_clicked();
    void on_mcuGuideEast_toggled(bool bOn);
    void on_mcuGuideWest_toggled(bool bOn);
    void on_mcuStart_toggled(bool bOn);
    void on_mcuPause_toggled(bool bOn);
    void mcuTimer();

    void on_toggleChartPeRaw_toggled(bool bOn);
    void on_toggleChartPeProcessed_toggled(bool bOn);
    void on_toggleChartPec_toggled(bool bOn);
    void on_toggleChartPecProfile_toggled(bool bOn);
    void on_toggleChartPeResidual_toggled(bool bOn);

private:
    bool mcuCommunicationBegin();
    void mcuCommunicationEnd();

    void openPeFile(const QString &qsFileName);

    void openPecFile(const QString &qsFileName);
    void savePecFile(const QString &qsFileName);
    void getPecTable();
    void putPecTable();
    void calcPecParams(bool bRedrawPecChart = true);
    void calcPecTable();
    void fillPecModel();

    void clearPecProfile();
    void startPecProfile(bool bSetSpeed);
    void stopPecProfile();
    void openPecProfileFile(const QString &qsFileName);
    void savePecProfileFile(const QString &qsFileName);

    void recalcPeData();
    void recalcPeriods();
    void recalcPeProcessed();
    void recalcPeChart();

private:
    Ui::MainWindow *m_pUi;
    QDir m_oCurrentDirectory;
    McuLogDialog *m_pMcuLog;
    IPeRawData *m_pPeRaw;
    QList<PePureSample> m_lstPePure;
    QList<Period> m_lstPeriod;
    QVector<QList<double> > m_aPeSorted;
    QVector<double> m_aPeCombined;
    QVector<double> m_aPeProcessed;
    double m_dfSiderealDay;
    int m_nWormWheelTeeth;
    double m_dfPecPosScale;
    PecData m_oPecTable;
    enum Dir { east, west, stop };
    Dir m_eGuideDir;
    QList<PeRawSample> m_lstPecProfile;
    QStandardItemModel *m_pPeProcessedModel;
    QStandardItemModel *m_pPecModel;
    QStandardItemModel *m_pPecProfileModel;
    QGraphicsScene *m_pPeChart;
    QTimer *m_pMcuTimer;
    McuSerial *m_pMcuPort;
    };


#endif // ASPECT_MAINWINDOW_H

